mock

package
v0.0.0-...-dd7b778 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 18, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package mock is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockMQClientProxy

type MockMQClientProxy struct {
	// contains filtered or unexported fields
}

MockMQClientProxy is a mock of MQClientProxy interface.

func NewMockMQClientProxy

func NewMockMQClientProxy(ctrl *gomock.Controller) *MockMQClientProxy

NewMockMQClientProxy creates a new mock instance.

func (*MockMQClientProxy) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockMQClientProxy) TestMQAdd

TestMQAdd mocks base method.

type MockMQClientProxyMockRecorder

type MockMQClientProxyMockRecorder struct {
	// contains filtered or unexported fields
}

MockMQClientProxyMockRecorder is the mock recorder for MockMQClientProxy.

func (*MockMQClientProxyMockRecorder) TestMQAdd

func (mr *MockMQClientProxyMockRecorder) TestMQAdd(ctx, req any, opts ...any) *gomock.Call

TestMQAdd indicates an expected call of TestMQAdd.

type MockMQService

type MockMQService struct {
	// contains filtered or unexported fields
}

MockMQService is a mock of MQService interface.

func NewMockMQService

func NewMockMQService(ctrl *gomock.Controller) *MockMQService

NewMockMQService creates a new mock instance.

func (*MockMQService) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockMQService) TestMQAdd

TestMQAdd mocks base method.

type MockMQServiceMockRecorder

type MockMQServiceMockRecorder struct {
	// contains filtered or unexported fields
}

MockMQServiceMockRecorder is the mock recorder for MockMQService.

func (*MockMQServiceMockRecorder) TestMQAdd

func (mr *MockMQServiceMockRecorder) TestMQAdd(ctx, req any) *gomock.Call

TestMQAdd indicates an expected call of TestMQAdd.

Jump to