Documentation
¶
Overview ¶
Package mock is a generated GoMock package.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockMQClientProxy ¶
type MockMQClientProxy struct {
// contains filtered or unexported fields
}
MockMQClientProxy is a mock of MQClientProxy interface.
func NewMockMQClientProxy ¶
func NewMockMQClientProxy(ctrl *gomock.Controller) *MockMQClientProxy
NewMockMQClientProxy creates a new mock instance.
func (*MockMQClientProxy) EXPECT ¶
func (m *MockMQClientProxy) EXPECT() *MockMQClientProxyMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockMQClientProxy) TestMQAdd ¶
func (m *MockMQClientProxy) TestMQAdd(ctx context.Context, req *mq.TestMQAddRequest, opts ...client.Option) (*mq.TestMQAddResponse, error)
TestMQAdd mocks base method.
type MockMQClientProxyMockRecorder ¶
type MockMQClientProxyMockRecorder struct {
// contains filtered or unexported fields
}
MockMQClientProxyMockRecorder is the mock recorder for MockMQClientProxy.
type MockMQService ¶
type MockMQService struct {
// contains filtered or unexported fields
}
MockMQService is a mock of MQService interface.
func NewMockMQService ¶
func NewMockMQService(ctrl *gomock.Controller) *MockMQService
NewMockMQService creates a new mock instance.
func (*MockMQService) EXPECT ¶
func (m *MockMQService) EXPECT() *MockMQServiceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockMQService) TestMQAdd ¶
func (m *MockMQService) TestMQAdd(ctx context.Context, req *mq.TestMQAddRequest) (*mq.TestMQAddResponse, error)
TestMQAdd mocks base method.
type MockMQServiceMockRecorder ¶
type MockMQServiceMockRecorder struct {
// contains filtered or unexported fields
}
MockMQServiceMockRecorder is the mock recorder for MockMQService.
Click to show internal directories.
Click to hide internal directories.